@@ -4,6 +4,7 @@ sub new {
 	my ($class) = @_;
 
 	my $self = {
+		delimiter => Delimiter->new,
 	};
 
 	$class = ref($class) || $class;
@@ -27,11 +28,13 @@ sub grep_char {
 }
 
 sub grep_clause {
-	my ($self, $string, $idx) = @_;
+	my ($self, $string, $index, $delimiter) = @_;
 	my $fwclause = FlyweightClause->new; 
 	my $s = "";
 
-	for (my $i = $idx; $delimiter != $string[$i]; $i++) {
+	$self->{delimiter} = $delimiter;
+
+	for (my $i = $index->get; $self->{delimiter} != $string[$i]; $i++) {
 
 		$s .= $string[$i];
 
